import SpinnerButton from "./ak-spinner-button.js";

export { SpinnerButton };
export default SpinnerButton;
